@@ -2,6 +2,7 @@
 
 # Released under the MIT License.
 # Copyright, 2021-2025, by Samuel Williams.
+# Copyright, 2025, by Shopify Inc.
 
 require "async/scheduler"
 
@@ -15,13 +16,20 @@ describe Async::Scheduler do
 		let(:duration) {0.01}
 		
 		it "can sleep for a short duration" do
-			expect(reactor).to receive(:kernel_sleep).with(duration)
+			sleeps = []
+			
+			mock(reactor) do |mock|
+				mock.before(:kernel_sleep) do |duration|
+					sleeps << duration
+				end
+			end
 			
 			time_taken = Async::Clock.measure do
 				sleep(duration)
 			end
 			
 			expect(time_taken).to be_within(Sus::Fixtures::Time::QUANTUM).of(duration)
+			expect(sleeps).to be(:include?, duration)
 		end
 		
 		it "can sleep forever" do
