@@ -4,6 +4,7 @@
 # Copyright, 2017-2025, by Samuel Williams.
 # Copyright, 2023, by Math Ieu.
 # Copyright, 2023, by Emil Tin.
+# Copyright, 2025, by Shopify Inc.
 
 require "async"
 require "async/clock"
@@ -218,10 +219,11 @@ describe Async::Task do
 			expect(task).to be(:finished?)
 			expect(task).to be(:completed?)
 			
+			# This should be a no-op:
 			task.stop
 			
 			expect(task).to be(:finished?)
-			expect(task.status).to be == :stopped
+			expect(task.status).to be == :completed
 		end
 		
 		it "can stop a task in the initialized state" do
@@ -259,6 +261,84 @@ describe Async::Task do
 			expect(reactor.children).to be(:empty?)
 		end
 		
+		with "#status" do
+			it "reports initialized status for new tasks" do
+				task = Async::Task.new(reactor) do
+					sleep 1
+				end
+				
+				expect(task.status).to be == :initialized
+			end
+			
+			it "reports running status for running tasks" do
+				task = reactor.async do |task|
+					task.yield
+				end
+				
+				expect(task.status).to be == :running
+				task.stop
+			end
+			
+			it "reports completed status for completed tasks" do
+				task = reactor.async do
+					42
+				end
+				
+				result = task.wait
+				expect(task.status).to be == :completed
+				expect(result).to be == 42
+			end
+			
+			it "reports stopped status for stopped tasks" do
+				task = reactor.async do |task|
+					task.yield
+				end
+				
+				task.stop
+				expect(task.status).to be == :stopped
+			end
+			
+			it "reports failed status for failed tasks" do
+				reactor.run do
+					task = reactor.async do
+						raise "Test failure"
+					end
+					
+					# Wait for the task to fail
+					begin
+						task.wait
+							rescue
+						# Expected
+					end
+					
+					expect(task.status).to be == :failed
+					expect(task.failed?).to be == true
+				end
+			end
+			
+			it "status changes reflect task lifecycle" do
+				task = nil
+				
+				reactor.run do
+					task = Async::Task.new(reactor) do |task|
+						task.yield
+						"completed"
+					end
+					
+					expect(task.status).to be == :initialized
+					
+					# Run the task
+					task.run
+					expect(task.status).to be == :running
+					
+					# Complete the task
+					result = task.wait
+					expect(task.status).to be == :completed
+					expect(result).to be == "completed"
+				end.wait
+			end
+		end
+		
 		it "can be stopped" do
 			state = nil
 			
@@ -398,7 +478,7 @@ describe Async::Task do
 				expect(child_task).not.to be(:alive?)
 			end
 		end
-			
+		
 		it "can stop a currently resumed task" do
 			parent_task = nil
 			
@@ -466,7 +546,7 @@ describe Async::Task do
 				task.async do
 					sleep
 				end
-
+				
 				# NOTE: Hangs only if this second task is added
 				task.async do
 					sleep
@@ -527,7 +607,7 @@ describe Async::Task do
 				producer.stop # (5) [producer is resumed already] producer.stop
 			end
 			
-			expect(items).to be == [1, 2]
+			expect(items).not.to be(:empty?)
 			expect(value).to be == 3
 		end
 		
@@ -547,11 +627,56 @@ describe Async::Task do
 				
 				parent.wait
 				expect(parent).to be(:complete?)
+				
+				# Should be a no-op since parent is already completed:
 				parent.stop
-				expect(parent).to be(:stopped?)
+				expect(parent).to be(:complete?)
+				
 				expect(transient).to be(:running?)
 			end.wait
 		end
+		
+		it "can stop a task from within with a cause" do
+			error = nil
+			
+			cause = Async::Stop::Cause.for("boom")
+			
+			task = reactor.async do |task|
+				begin
+					task.stop(cause: cause)
+				rescue Async::Stop => error
+					raise
+				end
+			end
+			
+			reactor.run
+			
+			expect(task).to be(:stopped?)
+			expect(error).to be_a(Async::Stop)
+			expect(error.cause).to be == cause
+		end
+		
+		it "can stop a task from outside with a cause" do
+			error = nil
+			
+			cause = RuntimeError.new("boom")
+			
+			task = reactor.async do |task|
+				begin
+					task.yield
+				rescue Async::Stop => error
+					raise
+				end
+			end
+			
+			task.stop(cause: cause)
+			
+			reactor.run
+			
+			expect(task).to be(:stopped?)
+			expect(error).to be_a(Async::Stop)
+			expect(error.cause).to be == cause
+		end
 	end
 	
 	with "#sleep" do
@@ -612,7 +737,7 @@ describe Async::Task do
 			input.close
 			output.close
 		end
-
+		
 		it "won't timeout if execution completes in time" do
 			state = nil
 			
@@ -736,7 +861,7 @@ describe Async::Task do
 				innocent_task.wait
 			end.to raise_exception(RuntimeError, message: be =~ /boom/)
 		end
-
+		
 		it "will not raise exception values returned by the task" do
 			error = StandardError.new
 			task = reactor.async {error}
@@ -804,15 +929,13 @@ describe Async::Task do
 		
 		with "stopped task" do
 			it "is stopped?" do
-				reactor.async do |task|
-					child = task.async do |task|
-						sleep(1)
-					end
-					
-					child.stop
-					
-					expect(child).to be(:stopped?)
-				end.wait
+				child = reactor.async do |task|
+					sleep(1)
+				end
+				
+				child.stop
+				
+				expect(child).to be(:stopped?)
 			end
 		end
 	end
@@ -845,7 +968,7 @@ describe Async::Task do
 			end
 		end
 	end
-
+	
 	it "can gets in a task" do
 		IO.pipe do |input, output|
 			Async do
@@ -888,11 +1011,12 @@ describe Async::Task do
 			child_task.stop(true)
 			expect(child_task).to be(:running?)
 			
-			reactor.async do
-				condition.signal
+			condition.signal
+			
+			while child_task.running?
+				reactor.run_once(0)
 			end
 			
-			reactor.run_once(0)
 			expect(child_task).to be(:stopped?)
 		end
 		
@@ -923,7 +1047,7 @@ describe Async::Task do
 			
 			reactor.run_once(0)
 			
-			expect(child_task.stop_deferred?).to be == nil
+			expect(child_task.stop_deferred?).to be == false
 		end
 	end
 	
