@@ -1,7 +1,8 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2022-2024, by Samuel Williams.
+# Copyright, 2022-2025, by Samuel Williams.
+# Copyright, 2025, by Shopify Inc.
 
 require "sus/fixtures/async"
 
@@ -10,9 +11,17 @@ describe Kernel do
 	
 	with "#sleep" do
 		it "can intercept sleep" do
-			expect(reactor).to receive(:kernel_sleep).with(0.001)
+			sleeps = []
+			
+			mock(reactor) do |mock|
+				mock.before(:kernel_sleep) do |duration|
+					sleeps << duration
+				end
+			end
 			
 			sleep(0.001)
+			
+			expect(sleeps).to be(:include?, 0.001)
 		end
 	end
 	
